@@ -2,11 +2,15 @@
 from threading import currentThread
 
 from django.utils.deprecation import MiddlewareMixin
+from django_utils.mock_request import MockRequest
 
 _requests = {}
 
 def get_request():
-    return _requests[currentThread()]
+    try:
+        return _requests[currentThread()]
+    except:
+        return None
 
 def get_thread_user():
     try:
@@ -33,4 +37,20 @@ class GlobalRequestMiddleware(MiddlewareMixin):
         set_request(request)
         response = self.get_response(request)
         delete_request()
-        return response
\ No newline at end of file
+        return response
+
+def with_global_user(func):
+    def wrapped_func(*args, _user=None, **kwargs):
+        if len(args) > 0:
+            if hasattr(args[0], 'user'):
+                user = args[0].user
+        if 'user'in kwargs:
+            user = kwargs['user']
+        if _user:
+            user = _user
+        assert user is not None, "User can't be none"
+        set_request(MockRequest(user))
+        res = func(*args, **kwargs)
+        delete_request()
+        return res
+    return wrapped_func
\ No newline at end of file
